`timescale 1ps / 1ps


module FlashWrapper#(
                      parameter ADDR_X_WIDTH = 4,
                      parameter ADDR_Y_WIDTH = 3,
                      parameter DOUT_WIDTH   = 8
                    ) 
                    ( 
                      input  logic                                 arst,
                      input  logic                                 controlFlash_r,
                      output logic                                 controlFlash_a,
                      input  logic                                 controlFlash_d,
                      input  logic                                 SE_Req,
                      output logic [DOUT_WIDTH-1:0]                SE_Data,
                      output logic                                 SE_Ack,
                      input  logic                                 adr_Req,
                      input  logic [ADDR_X_WIDTH+ADDR_Y_WIDTH-1:0] adr_Data,
                      output logic                                 adr_Ack,
                      input  logic [3:0]                           dataRead_r,
                      output logic [3:0]                           dataRead_a,
                      input  logic [3:0][DOUT_WIDTH-1:0]           dataRead_d
                    );



  logic                      IFREN;
  logic  [1:0]               REDEN;
  logic  [ADDR_X_WIDTH-1:0]  XADR;
  logic                      XE;
  logic  [ADDR_Y_WIDTH-1:0]  YADR;
  logic                      YE;
  logic                      PV;
  logic                      EV;
  logic                      SE;
  logic                      controlFlash;
  logic                      dataValid;
  logic  [DOUT_WIDTH*4-1:0]  dataRead;


  assign #1ns controlFlash_a = controlFlash_r;
  always_latch begin
    if (arst)
      controlFlash = 0;
    else if(controlFlash_r)
      controlFlash = controlFlash_d;
  end

  always_comb begin
    if (controlFlash == 1) begin
      IFREN = 0;
      REDEN = 0;
      XADR  = adr_Data[ADDR_X_WIDTH-1:0];
      XE    = 1'b1;
      YADR  = adr_Data[ADDR_X_WIDTH+ADDR_Y_WIDTH-1:ADDR_X_WIDTH];
      YE    = 1'b1;
      PV    = 0;
      EV    = 0;
      SE    = SE_Req;
    end 
    else begin
      IFREN = 0;
      REDEN = 0;
      XADR  = 0;
      XE    = 1'b0;
      YADR  = 0;
      YE    = 1'b0;
      PV    = 0;
      EV    = 0;
      SE    = 0;
    end
  end



  assign #1ns adr_Ack = adr_Req;
  assign SE_Ack = SE_Req & dataValid; 
  
  Flash    #(
            .ADDR_X_WIDTH  (ADDR_X_WIDTH), 
            .ADDR_Y_WIDTH  (ADDR_Y_WIDTH), 
            .DOUT_WIDTH    (DOUT_WIDTH ) 
             )
    u_Flash (
             .IFREN      (IFREN),
             .REDEN      (REDEN),
             //.XADR       (adr_Data[ADDR_X_WIDTH-1:0]),
             .XADR       (XADR),
             .XE         (XE),
             //.YADR       (adr_Data[ADDR_X_WIDTH+ADDR_Y_WIDTH-1:ADDR_X_WIDTH]),
             .YADR       (YADR),
             .YE         (YE),
             .PV         (PV),
             .EV         (EV),
             .SE         (SE_Req),
             .DATAVALID  (dataValid),
             .DOUT       (SE_Data)
             );



  assign #1ns dataRead_a = dataRead_r;
  always_latch  begin
    if (arst)
      dataRead = 0;
    else begin
      if(dataRead_r[0])
        dataRead[7:0]   = dataRead_d;
      if(dataRead_r[1])
        dataRead[15:8]  = dataRead_d;
      if(dataRead_r[2])
        dataRead[23:16] = dataRead_d;
      if(dataRead_r[3])
        dataRead[31:23] = dataRead_d;
    end
  end

//initial begin
//  IFREN = 0;
//  REDEN = 0;
//  PV = 0;
//  EV =0;
//  XE = 1'b1;
//  YE = 1'b1;
//end


endmodule
